#! /bin/bash

#
# Script that starts up bash script based on amqpfind messages
#
# Note - when using Full Disk make sure -n is set to 7. Otherwise, `Disk' will be passed to the next call to the script.

set -e 

module load gcc/6.1
module load hdf/4.2.12-nocdf
module load hdf5/1.8.17
module load netcdf3/3.6.3
module load netcdf4/4.4.1
module load miniconda/3.19-base
#module load miniconda/3.6-base
module list



export COVERAGE=Full Disk
export PATH=$PWD:$PATH



#This routine will send a notification email 1/hour if the messages time out
send_failure_mail() {

 ### allow only one email per hour 
    tag="$(date '+%Y%m%dT%H')" 
    
    if [[ "$tag" != "$old_tag" ]]
    then 
#       date | mail -s "GRB timeout" kbah@ssec.wisc.edu      
        echo "GOES-R/S timeout email"
        old_tag=$tag
     fi 
}


# use a marker file instead of a global variable
# marker file is first parameter
# period is second parameter: 3h, 4h, 1d, see find command manpage
send_failure_mail_touchnfind() {
    marker="$1"
    delta="$2"
    marker_dir="$(dirname $marker)"
    test -z "$marker_dir" && marker_dir=.
    marker_fn="$(basename $marker)"
    # look for a marker that's younger than ${delta}; if none exists, send mail and touch marker
    if [ -z "$(find $marker_dir -name $marker_fn -mtime -${delta} -maxdepth 1)" ]; then
      date |mail -s "GRB timeout" ${USER}@ssec.wisc.edu
      touch $marker
    fi
}

 echo START OF LOOP
 
    $HOME/test/code/amqpfind/amqpfind -H mq1.ssec.wisc.edu -p sdsmq -u sdsuser \
    -H mq2.ssec.wisc.edu -p sdsmq -u sdsuser \
    -k '(start_time, coverage)' \
    -w 60.0 \
    -X satellite \
    -j '{start_time} {adde_dataset} {server_ip} {satellite_location} {coverage} {path}' \
    -C geo.goes.g17.abi.adde.realtime.*.image.complete |grep --line-buffered -i ${COVERAGE} | xargs -n8  ${PWD}/callCLAVR.bash


  echo END OF LOOP

